Learn R Programming

matchingR (version 1.1.1)

checkStabilityTopTradingCycle: Check if a one-sided matching for the top trading cycle algorithm is stable

Description

Check if a one-sided matching for the top trading cycle algorithm is stable

Usage

checkStabilityTopTradingCycle(pref, matchings)

Arguments

pref
is a matrix with ordinal rankings of the participants
matchings
is an nx1 matrix encoding who is matched to whom using R style indexing

Value

  • true if the matching is stable, false otherwise