Learn R Programming

matchingR (version 1.3.0)

galeShapley.checkPreferences: Check if preference order is complete

Description

This function checks if a given preference ordering is complete. If needed, it transforms the indices from R indices (starting at 1) to C++ indices (starting at zero).

Usage

galeShapley.checkPreferences(pref)

Arguments

pref

is a matrix with ordinal preference orderings for one side of the market. Suppose that pref refers to the preferences of n women over m men. In that case, pref will be of dimension m by n. The i,jth element refers to woman j's ith most favorite man. Preference orders can either be specified using R-indexing (starting at 1) or C++ indexing (starting at 0).

Value

a matrix with ordinal preference orderings with proper C++ indices or NULL if the preference order is not complete.

Examples

Run this code
# NOT RUN {
# preferences in proper C++ indexing: galeShapley.checkPreferences(pref)
# will return pref
pref = matrix(c(0, 1, 0,
                1, 0, 1), nrow = 2, ncol = 3, byrow = TRUE)
pref
galeShapley.checkPreferences(pref)

# preferences in R indexing: galeShapley.checkPreferences(pref)
# will return pref-1
pref = matrix(c(1, 2, 1,
                2, 1, 2), nrow = 2, ncol = 3, byrow = TRUE)
pref
galeShapley.checkPreferences(pref)

# incomplete preferences: galeShapley.checkPreferences(pref)
# will return NULL
pref = matrix(c(3, 2, 1,
                2, 1, 2), nrow = 2, ncol = 3, byrow = TRUE)
pref
galeShapley.checkPreferences(pref)
# }

Run the code above in your browser using DataLab