Rdocumentation
powered by
Learn R Programming
matchingR (version 1.1.1)
sortIndex: Sort indices of a matrix within a column
Description
Within each column of a matrix, this function returns the indices of each element in descending order
Usage
sortIndex(u)
Arguments
u
is the input matrix
Value
a matrix with sorted indicies