Learn R Programming

matchingR (version 1.1.1)

sortIndexOneSided: Ranks elements with column of a matrix, assuming a one-sided market.

Description

Returns the rank of each element with each column of a matrix. So, if row 34 is the highest number for column 3, then the first row of column 3 will be 34 -- unless it is column 34, in which case it will be 35, to adjust for the fact that this is a single-sided market.

Usage

sortIndexOneSided(u)

Arguments

u
A matrix with agent's cardinal preferences. Column i is agent i's preferences.

Value

  • A list with the matchings made.