one2one, many2one,
one2many.galeShapleyMatching(proposerPref, reviewerUtils)proposals is a vector whose nth element contains the id of the reviewer
that proposer n is matched to (using C++ indexing that starts at zero).
engagements is a vector whose nth element contains the id of the proposer
that reviewer n is matched to (using C++ indexing that starts at zero).