one2one() instead that allows for
more flexible input choices.galeShapleyMatching(proposerPref, reviewerUtils)proposals is a vector whose nth element contains the id of the reviewer
that proposer n is matched to.
engagements is a vector whose nth element contains the id of the proposer
that reviewer n is matched to.