validateInputsOneSided: Input validation for one-sided markets
Description
This function parses and validates the arguments for one sided preferences
for the function onesided. If it uses R-style indexing (i.e., beginning at
1), then it re-numbers the preference matrix to use C++ style indexing.
Usage
validateInputsOneSided(pref = NULL, utils = NULL)
Arguments
pref
is an n-1xn matrix, with each row representing an ordinal ranking.
utils
if an n-1xn matrix, with each row representing the cardinal preferences
of the agents.
Value
The validated inputs, ready to be sent to C++ code.